import { buildProps } from '../../../../utils/buildHelper.mjs';

const propsTypes = buildProps({
  url: {
    required: true,
    type: String
  },
  // 瓦片地址，支持 {s} {x} {y} {z}，示例：http://webst0{s}.is.autonavi.com/appmaptile?style=6&x={x}&y={y}&z={z}
  subdomains: {
    type: Array
  },
  // 子域名数组，当url中设置{s}后，该属性必填
  tileType: {
    type: String,
    default: "xyz",
    validator: (value) => {
      return ["xyz", "bd09"].indexOf(value) !== -1;
    }
  },
  // 瓦片分割类型，默认是xyz，xyz代表瓦片是编号是从左上角开始，百度瓦片是由中间开始，所以需要区分普通瓦片还是百度
  proj: {
    type: String,
    default: "gcj02",
    validator: (value) => {
      return ["wgs84", "gcj02", "bd09"].indexOf(value) !== -1;
    }
  },
  // 瓦片使用的坐标系，默认是gcj02
  zooms: {
    type: Object
  },
  // 图层缩放等级范围，默认 [2, 18]
  opacity: {
    type: Number
  },
  // 图层透明度，默认为 1
  zIndex: {
    type: Number,
    default: 120
  },
  mask: {
    type: Array
  },
  cacheSize: {
    type: Number,
    default: 512
  },
  debug: {
    type: Boolean,
    default: false
  },
  tileMaxZoom: {
    type: Number
  },
  altitude: {
    type: Number
  }
});

export { propsTypes };
//# sourceMappingURL=props.mjs.map
